Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5361)

Unified Diff: chrome/browser/custom_home_pages_table_model.h

Issue 6693021: fav icon -> favicon. Pass 5: fav_icon -> favicon (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 9 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/chromeos/wm_overview_favicon.cc ('k') | chrome/browser/custom_home_pages_table_model.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/custom_home_pages_table_model.h
diff --git a/chrome/browser/custom_home_pages_table_model.h b/chrome/browser/custom_home_pages_table_model.h
index b452e8da904990b95453062950f5460a730639d2..0ef060b9718df98ae0900631cc40f89154e16183 100644
--- a/chrome/browser/custom_home_pages_table_model.h
+++ b/chrome/browser/custom_home_pages_table_model.h
@@ -69,9 +69,9 @@ class CustomHomePagesTableModel : public ui::TableModel {
history::VisitVector* visits);
// Callback from history service. Updates the icon of the Entry whose
// |fav_icon_handle| matches |handle| and notifies the observer of the change.
void OnGotFavIcon(FaviconService::Handle handle,
- bool know_fav_icon,
+ bool know_favicon,
scoped_refptr<RefCountedMemory> image_data,
bool is_expired,
GURL icon_url);
@@ -82,7 +82,7 @@ class CustomHomePagesTableModel : public ui::TableModel {
CancelableRequestProvider::Handle handle,
int* entry_index);
// Returns the entry whose |fav_icon_handle| matches |handle| and sets
// |entry_index| to the index of the entry.
Entry* GetEntryByFavIconHandle(FaviconService::Handle handle,
int* entry_index);
@@ -69,9 +69,9 @@ class CustomHomePagesTableModel : public ui::TableModel {
history::VisitVector* visits);
// Callback from history service. Updates the icon of the Entry whose
- // |fav_icon_handle| matches |handle| and notifies the observer of the change.
+ // |favicon_handle| matches |handle| and notifies the observer of the change.
void OnGotFavIcon(FaviconService::Handle handle,
@@ -82,7 +82,7 @@ class CustomHomePagesTableModel : public ui::TableModel {
CancelableRequestProvider::Handle handle,
int* entry_index);
- // Returns the entry whose |fav_icon_handle| matches |handle| and sets
+ // Returns the entry whose |favicon_handle| matches |handle| and sets
// |entry_index| to the index of the entry.
Entry* GetEntryByFavIconHandle(FaviconService::Handle handle,
« no previous file with comments | « chrome/browser/chromeos/wm_overview_favicon.cc ('k') | chrome/browser/custom_home_pages_table_model.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698